package com.example.pageobjects.pakistan;

import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;

public class BayanatPage {
    public WebDriver driver;

    public BayanatPage(WebDriver driver) {
        this.driver = driver;
    }

    public WebElement firstNameFieldLocator() {
        return driver.findElement(By.cssSelector("input[name='first_name']"));
    }

    public WebElement lastNameFieldLocator() {
        return driver.findElement(By.cssSelector("input[name='last_name']"));
    }

    public WebElement emailFieldLocator() {
        return driver.findElement(By.xpath("//input[@id='form_email']"));
    }

    public WebElement phoneFieldLocator() {
        return driver.findElement(By.cssSelector("input[name='phone']"));
    }

    public WebElement addressFieldLocator() {
        return driver.findElement(By.cssSelector("input[name='address']"));
    }

    public WebElement cityFieldLocator() {
        return driver.findElement(By.cssSelector("input[name='city']"));
    }

    public WebElement countryFieldLocator() {
        return driver.findElement(By.cssSelector("input[name='country']"));
    }

    public WebElement skillsFieldLocator() {
        return driver.findElement(By.cssSelector("textarea[name='qualification']"));
    }

    public WebElement volunteerExperienceFieldLocator() {
        return driver.findElement(By.cssSelector("textarea[name='experience']"));
    }

    public WebElement successAlertMessageLocator() {
        return driver.findElement(By.xpath("//div[@class='alert alert-success alert-dismissible']"));
    }

}
